Learn R Programming

R.matlab (version 3.8.0)

finalize.Matlab: (internal) Finalizes the object if deleted

Description

(internal) Finalizes the object if deleted. If a MATLAB connection is opened, it is closed.

Note that you should never have to call this method explicitly. It is called automatically whenever the object is removed from memory (by the garbage collector).

Usage

# S3 method for Matlab
finalize(this, ...)

Arguments

Value

Returns nothing.

See Also

For more information see Matlab.