Learn R Programming

R.matlab (version 3.8.0)

setVerbose.Matlab: Sets the verbose level to get more details about the MATLAB access

Description

Sets the verbose level to get more details about the MATLAB access.

Usage

# S3 method for Matlab
setVerbose(this, threshold=0, ...)

Arguments

Value

Returns the previous threshold value (an integer) used.

Details

If the threshold is set to zero (default) general comments about the MATLAB access is given, such as the MATLAB server is started etc. If the threshold is -1, details about the communication with the MATLAB server is given. If the threshold is -2, low-level details about the communication with the MATLAB server is given, such as what commands are sent etc.

See Also

For more information see Matlab.