Sets the value of an option where the option is specified like a file pathname, e.g. "readResult/maxTries". See the Options class for details.
# S3 method for Matlab
setOption(this, ...)Returns the previous value of the option.
Arguments passed to
setOption()
of the Options class.
The maximum number of times the connection is check for an answer from the MATLAB server before giving up. Default values is 30 times.
The interval in seconds between each poll for an answer. Default interval is 1 (second).
With default values of the above options, the R MATLAB client waits 30 seconds for a reply from the MATLAB server before giving up.
Henrik Bengtsson
*getOption().
For more information see Matlab.